==> nextcloud-app-mail-0.6.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nb_NO.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-post",
    "Error while loading the accounts." : "Feil ved innlasting av kontoene.",
    "Fetching Aliases Failed." : "Henting av aliaser feilet.",
    "Saving Aliases Failed." : "Lagring av aliaser feilet.",
    "Deleting Aliases Failed." : "Sletting av aliaser feilet.",
    "Error while loading the selected account." : "Feil ved lasting av den valgte kontoen.",
    "Loading {folder}" : "Laster {folder}",
    "Searching for {query}" : "Søker etter {query}",
    "Forwarded message" : "Videresendt melding",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Attachments saved to Files." : "Vedleggene ble lagret i Filer.",
    "Attachment saved to Files." : "Vedlegget ble lagret i Filer.",
    "Error while saving attachments to Files." : "Feil ved lagring av vedleggene i Filer.",
    "Error while saving attachment to Files." : "Feil ved lagring av vedlegget i Filer.",
    "Message flag could not be set." : "Meldingsflagget kunne ikke settes.",
    "Invalid account" : "Ugyldig konto",
    "Invalid folder" : "Ugyldig mappe",
    "Unknown error" : "Ukjent feil",
    "Error while creating an account: " : "Feil ved oppretting av en konto:",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Vi kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
    "We couldn’t load your message" : "Vi kunne ikke laste meldingen din",
    "Unable to load the desired message" : "Kan ikke laste ønsket melding",
    "There was a problem loading the message" : "Det oppstod et problem under lasting av meldingen",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n ny melding i {folderName} \nfra {from}","%n nye meldinger i {folderName} \nfra {from}"],
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Skjul mapper",
    "Error while deleting account." : "Feil ved sletting av konto.",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "Reply" : "Svar",
    "Send" : "Send",
    "Sending …" : "Sender ...",
    "Message sent!" : "Melding sendt!",
    "Server error" : "Tjenerfeil",
    "An unknown error occurred" : "En ukjent feil oppstod",
    "Opening HTML drafts is not supported yet." : "Åpning av HTML-kladd er ikke støttet ennå.",
    "Draft saved!" : "Kladd lagret!",
    "you" : "du",
    "Send message to {email}" : "Send melding til {email}",
    "No writable calendars found" : "Ingen skrivbare kalendere funnet",
    "Error while importing the calendar event" : "Feil ved importering av kalenderhendelse",
    "Error while downloading calendar event" : "Feil ved nedlasting av kalenderhendelse",
    "Error while deleting message." : "Feil ved sletting av melding.",
    "Error while loading messages." : "Feil ved innlasting av meldinger.",
    "Connecting" : "Kobler til",
    "Connect" : "Koble til",
    "Inbox" : "Innboks",
    "Sent" : "Sendt",
    "Drafts" : "Kladd",
    "Archive" : "Arkiv",
    "Trash" : "Papirkurv",
    "Junk" : "Søppel",
    "All" : "Alle",
    "Favorites" : "Favoritter",
    "Creating account failed: " : "Oppretting av konto feilet:",
    "Auto detect failed. Please use manual mode." : "Automatisk påvisning feilet. Bruk manuelt oppsett.",
    "Delete permanently" : "Slett permanent",
    "& others" : "& andre",
    "All inboxes" : "Alle innbokser",
    "Error loading message" : "Feil ved innlasting av melding",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir omdirigert automatisk innen noen få sekunder.",
    "Redirect" : "Omdiriger",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker å besøke den siden, kan du returnere til <a href=\"%s\">E-post</a>.",
    "Continue to %s" : "Fortsett til %s",
    "Settings" : "Innstillinger",
    "Delete account" : "Slett konto",
    "Account Settings" : "Kontoinnstillinger",
    "Aliases" : "Aliaser",
    "Mail address" : "E-postadresse",
    "Display Name" : "Visningsnavn",
    "Save" : "Lagre",
    "Add attachment from Files" : "Legg til vedlegg fra Filer",
    "from" : "fra",
    "to" : "ti",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Emne",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer",
    "Save all to Files" : "Lagre alle i Filer",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "Show images from this sender" : "Vis bilder fra denne avsenderen",
    "Forward" : "Videresend",
    "New message" : "Ny melding",
    "No search results for" : "Ingen søkeresultater for",
    "Add mail account" : "Legg til e-postkonto",
    "Connect your mail account" : "Koble til din e-postkonto",
    "Name" : "Navn",
    "Mail Address" : "E-postadresse",
    "Password" : "Passord",
    "Manual configuration" : "Manuelt oppsett",
    "IMAP Host" : "IMAP vert",
    "IMAP security" : "IMAP sikkerhet",
    "None" : "Ingen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP Bruker",
    "IMAP Password" : "IMAP Passord",
    "SMTP Host" : "SMTP vert",
    "SMTP security" : "SMTP sikkerhet",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP Bruker",
    "SMTP Password" : "SMTP Passord"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-0.7.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/nb_NO.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "E-post",
    "Error while loading the accounts." : "Feil ved innlasting av kontoene.",
    "Error while loading the selected account." : "Feil ved lasting av den valgte kontoen.",
    "Can not load this folder." : "Kan ikke laste denne mappen.",
    "Loading {folder}" : "Laster {folder}",
    "Searching for {query}" : "Søker etter {query}",
    "Forwarded message" : "Videresendt melding",
    "Choose a folder to store the attachment in" : "Velg en mappe å lagre vedlegget i",
    "Attachments saved to Files." : "Vedleggene ble lagret i Filer.",
    "Attachment saved to Files." : "Vedlegget ble lagret i Filer.",
    "Error while saving attachments to Files." : "Feil ved lagring av vedleggene i Filer.",
    "Error while saving attachment to Files." : "Feil ved lagring av vedlegget i filer.",
    "Message flag could not be set." : "Meldingsflagget kunne ikke settes.",
    "Could not move message." : "Kunne ikke flytte melding.",
    "Invalid account" : "Ugyldig konto",
    "Invalid folder" : "Ugyldig mappe",
    "Unknown error" : "Ukjent feil",
    "Error while creating the account: " : "Feil under opprettelse av kontoen:",
    "All inboxes" : "Alle innbokser",
    "Could not load {tag}{name}{endtag}" : "Kunne ikke laste {tag}{name}{endtag}",
    "We couldn’t load {tag}{name}{endtag}" : "Vi kunne ikke laste {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Det oppstod et problem under lasting av {tag}{name}{endtag}",
    "We couldn’t load your message" : "Vi kunne ikke laste meldingen din",
    "Unable to load the desired message" : "Kan ikke laste ønsket melding",
    "There was a problem loading the message" : "Det oppstod et problem under lasting av meldingen",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message in {folderName} \nfrom {from}_::_%n new messages in {folderName} \nfrom {from}_" : ["%n ny melding i {folderName} \nfra {from}","%n nye meldinger i {folderName} \nfra {from}"],
    "Show all folders" : "Vis alle mapper",
    "Collapse folders" : "Skjul mapper",
    "Error while deleting account." : "Feil ved sletting av konto.",
    "Choose a file to add as attachment" : "Velg en fil å legge til som vedlegg",
    "Reply" : "Svar",
    "Send" : "Send",
    "Sending …" : "Sender…",
    "Message sent!" : "Melding sendt!",
    "Server error" : "Tjenerfeil",
    "An unknown error occurred" : "En ukjent feil oppstod",
    "Opening HTML drafts is not supported yet." : "Åpning av HTML-kladd er ikke støttet ennå.",
    "Draft saved!" : "Kladd lagret!",
    "you" : "du",
    "Send message to {email}" : "Send melding til {email}",
    "No writable calendars found" : "Ingen skrivbare kalendere funnet",
    "Error while importing the calendar event" : "Feil ved importering av kalenderhendelse",
    "Error while downloading calendar event" : "Feil ved nedlasting av kalenderhendelse",
    "Error while deleting message." : "Feil ved sletting av melding.",
    "Error while loading messages." : "Feil ved innlasting av meldinger.",
    "Setting up your account" : "Oppsett av kontoen din",
    "Inbox" : "Innboks",
    "Sent" : "Sendt",
    "Drafts" : "Kladd",
    "Archive" : "Arkiv",
    "Trash" : "Papirkurv",
    "Junk" : "Søppel",
    "All" : "Alle",
    "Favorites" : "Favoritter",
    "Creating account failed: " : "Oppretting av konto mislyktes:",
    "Auto detect failed. Please use manual mode." : "Automatisk påvisning mislyktes. Bruk manuelt oppsett.",
    "Delete permanently" : "Slett for godt",
    "& others" : "og andre",
    "Error loading message" : "Feil ved innlasting av melding",
    "Settings" : "Innstillinger",
    "Forwarding to %s" : "Videresender til %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Klikk her hvis du ikke blir videresendt automatisk innen noen få sekunder.",
    "Redirect" : "Videresend",
    "The link leads to %s" : "Denne lenken leder til %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Hvis du ikke ønsker å besøke den siden, kan du returnere til <a href=\"%s\">E-post</a>.",
    "Continue to %s" : "Fortsett til %s",
    "Delete account" : "Slett konto",
    "Try again" : "Prøv igjen",
    "New message" : "Ny melding",
    "Account Settings" : "Kontoinnstillinger",
    "Aliases" : "Aliaser",
    "Mail address" : "E-postadresse",
    "Display Name" : "Visningsnavn",
    "Save" : "Lagre",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Speed up your Mail experience with these quick shortcuts." : "Arbeid raskere i Mail med disse raske snarveiene",
    "Newer message" : "Nyere melding",
    "Older message" : "Eldre melding",
    "Toggle star" : "Merk med stjerne",
    "Toggle unread" : "Merk som ulest",
    "Delete" : "Slett",
    "Search" : "Søk",
    "Refresh" : "Oppdater",
    "Connect your mail account" : "Koble til din e-postkonto",
    "Name" : "Navn",
    "Mail Address" : "E-postadresse",
    "Password" : "Passord",
    "Manual configuration" : "Manuelt oppsett",
    "IMAP Host" : "IMAP vert",
    "IMAP security" : "IMAP sikkerhet",
    "None" : "Ingen",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP Bruker",
    "IMAP Password" : "IMAP Passord",
    "SMTP Host" : "SMTP vert",
    "SMTP security" : "SMTP sikkerhet",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP Bruker",
    "SMTP Password" : "SMTP Passord",
    "Connect" : "Koble til",
    "from" : "fra",
    "to" : "ti",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Emne",
    "Save all to Files" : "Lagre alle i Filer",
    "Add mail account" : "Legg til e-postkonto",
    "No search results for" : "Ingen søkeresultater for",
    "The images have been blocked to protect your privacy." : "Bildene har blitt blokkert for å beskytte privatlivet.",
    "Show images from this sender" : "Vis bilder fra denne avsenderen",
    "Forward" : "Videresend",
    "Import into calendar" : "Importer til kalender",
    "Download attachment" : "Last ned vedlegg",
    "Save to Files" : "Lagre i Filer"
},
"nplurals=2; plural=(n != 1);");
